part of 'land_property_appraisal_bloc.dart';

class LandPropertyAppraisalState extends Equatable {
  const LandPropertyAppraisalState();

  @override
  List<Object> get props => [];
}

class LandPropertyAppraisalInitial extends LandPropertyAppraisalState {
  @override
  List<Object> get props => [];
}

class LandPropertyAppraisalLoaded extends LandPropertyAppraisalState {
  final List<LandAppr> landAppr;

  const LandPropertyAppraisalLoaded({required this.landAppr});
  @override
  List<Object> get props => [landAppr];
}

class LoadSpecificLandPropertyAppraisal extends LandPropertyAppraisalState {
  final LandAppr landAppr;

  const LoadSpecificLandPropertyAppraisal({required this.landAppr});
  @override
  List<Object> get props => [landAppr];
}

class ShowAddItemsScreen extends LandPropertyAppraisalState {}

class LandPropertyAppraisalErrorState extends LandPropertyAppraisalState {
  const LandPropertyAppraisalErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class LandPropertyAppraisalDeletedState extends LandPropertyAppraisalState {
  final bool success;
  const LandPropertyAppraisalDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
